@@ -136,7 +136,7 @@ svygeidec.survey.design <-
     incvar <- model.frame(formula, design$variables, na.action = na.pass)[,]
     grpvar <- model.frame( subgroup, design$variables, na.action = na.pass)[,]
 
-    if ( class(grpvar) == "labelled" ) {
+    if ( inherits(grpvar,"labelled") ) {
       stop( "This function does not support 'labelled' variables. Try factor().")
     }
 
@@ -368,7 +368,7 @@ svygeidec.svyrep.design <-
     incvar <- model.frame(formula, design$variables, na.action = na.pass)[,]
     grpvar <- model.frame( subgroup, design$variables, na.action = na.pass)[,]
 
-    if ( class(grpvar) == "labelled" ) {
+    if ( inherits(grpvar,"labelled") ) {
       stop( "This function does not support 'labelled' variables. Try factor().")
     }
 
