@@ -11,7 +11,7 @@
 #' @param na.rm Should cases with missing values be dropped?
 #' @param med_old return the median income of people older than agelim
 #' @param med_young return the median income of people younger than agelim
-#' @param ... arguments passed on to `survey::svyquantile`
+#' @param ... arguments passed on to `survey::oldsvyquantile`
 #'
 #' @details you must run the \code{convey_prep} function on your survey design object immediately after creating it with the \code{svydesign} or \code{svrepdesign} function.
 #'
@@ -139,7 +139,7 @@ svyrmir.survey.design  <-
 	}
 
 
-    q_alpha1 <- survey::svyquantile(x = formula, design = dsub1, quantiles = quantiles,method = "constant", na.rm = na.rm,...)
+    q_alpha1 <- survey::oldsvyquantile(x = formula, design = dsub1, quantiles = quantiles,method = "constant", na.rm = na.rm,...)
     q_alpha1 <- as.vector(q_alpha1)
 
     Fprime1 <- densfun(formula = formula, design = dsub1, q_alpha1, h=h, FUN = "F", na.rm=na.rm)
@@ -159,7 +159,7 @@ svyrmir.survey.design  <-
 
 
 
-    q_alpha2 <- survey::svyquantile(x = formula, design = dsub2, quantiles = quantiles, method = "constant", na.rm = na.rm,...)
+    q_alpha2 <- survey::oldsvyquantile(x = formula, design = dsub2, quantiles = quantiles, method = "constant", na.rm = na.rm,...)
     q_alpha2 <- as.vector(q_alpha2)
 
     Fprime2 <- densfun(formula = formula, design = dsub2, q_alpha2, h=h, FUN = "F", na.rm=na.rm)
